==> kubernetes-model-autoscaling-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends ContainerResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getTargetAverageUtilization();
  public A withTargetAverageUtilization(Integer targetAverageUtilization);
  public Boolean hasTargetAverageUtilization();
  public Quantity getTargetAverageValue();
  public A withTargetAverageValue(Quantity targetAverageValue);
  public Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(String amount,String format);
  public A withNewTargetAverageValue(String amount);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends ContainerResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getTargetAverageUtilization();
  public A withTargetAverageUtilization(Integer targetAverageUtilization);
  public Boolean hasTargetAverageUtilization();
  public Quantity getTargetAverageValue();
  public A withTargetAverageValue(Quantity targetAverageValue);
  public Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(String amount,String format);
  public A withNewTargetAverageValue(String amount);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
